@@ -4,6 +4,7 @@ from math import sin, cos, sqrt, atan2, radians
 from time import sleep
 import os
 from botocore.exceptions import ClientError
+from boto3.dynamodb.conditions import Attr
 from dateutil.parser import parse
 import boto3
 
@@ -96,6 +97,12 @@ def dict_to_dynamo(raw_dict):
             dynamo_dict[key] = decimal.Decimal(str(val))
         elif isinstance(val, dict):
             dynamo_dict[key] = dict_to_dynamo(raw_dict[key])
+        elif val is None:
+            #skip null values
+            continue
+        elif (val == ""):
+            # skip null values
+            continue
         else:
             dynamo_dict[key] = val
     return dynamo_dict
@@ -192,3 +199,33 @@ def download_files(files=None, bucket_name=None):
     except Exception as e:
         print('exception', e)
         print('traceback', traceback.format_exc())
+
+def query_table_distance(table_name, latitude, longitude, radius_km=.5, geo_hash_5=None, **kwargs):
+    # https://stackoverflow.com/questions/23117989/get-the-max-latitude-and-longitude-given-radius-meters-and-position?utm_medium=organic&utm_source=google_rich_qa&utm_campaign=google_rich_qa
+
+    longitude_degree_km = 111.320 * cos(latitude / 180.0 * pi)
+    delta_lat = radius_km / 111.1
+    delta_long = radius_km / longitude_degree_km
+
+    min_lat = decimal.Decimal(str(latitude - delta_lat))
+    max_lat = decimal.Decimal(str(latitude + delta_lat))
+    min_long = decimal.Decimal(str(longitude - delta_long))
+    max_long = decimal.Decimal(str(longitude + delta_long))
+
+    table_filter = {
+        'FilterExpression': Attr('latitude').between(min_lat, max_lat) & Attr('longitude').between(min_long, max_long)
+    }
+
+    if geo_hash_5:
+
+        table_filter = {
+            'IndexName': 'geoHash5' + '-index',
+            'KeyConditionExpression': Key('geoHash5').eq(geo_hash_5),
+            'FilterExpression': Attr('latitude').between(min_lat, max_lat) & Attr('longitude').between(min_long,
+                                                                                                       max_long)
+        }
+        items = get_dynamo_items(table_name, table_filter, table_get_type='query')
+    else:
+        items = get_dynamo_items(table_name, table_filter)
+
+    return items
\ No newline at end of file
